# Generated by Django 4.2.25 on 2025-10-08 16:20

from django.db import migrations, models

import wagtail_ai.models


class Migration(migrations.Migration):
    dependencies = [
        ("wagtail_ai", "0003_agentsettings"),
    ]

    operations = [
        migrations.AddField(
            model_name="agentsettings",
            name="page_description_prompt",
            field=models.TextField(
                blank=True,
                default=wagtail_ai.models.AgentPromptDefaults.page_description_prompt,
            ),
        ),
        migrations.AddField(
            model_name="agentsettings",
            name="page_title_prompt",
            field=models.TextField(
                blank=True,
                default=wagtail_ai.models.AgentPromptDefaults.page_title_prompt,
            ),
        ),
        migrations.AddField(
            model_name="agentsettings",
            name="contextual_alt_text_prompt",
            field=models.TextField(
                blank=True,
                default=wagtail_ai.models.AgentPromptDefaults.contextual_alt_text_prompt,
            ),
        ),
        migrations.AddField(
            model_name="agentsettings",
            name="image_description_prompt",
            field=models.TextField(
                blank=True,
                default=wagtail_ai.models.AgentPromptDefaults.image_description_prompt,
            ),
        ),
        migrations.AddField(
            model_name="agentsettings",
            name="image_title_prompt",
            field=models.TextField(
                blank=True,
                default=wagtail_ai.models.AgentPromptDefaults.image_title_prompt,
            ),
        ),
    ]
