# Generated by Django 5.2.5 on 2025-10-01 08:55

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wagtail_ai", "0002_populate_default_prompts"),
    ]

    operations = [
        migrations.CreateModel(
            name="AgentSettings",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("content_feedback_prompt", models.TextField(blank=True)),
                (
                    "content_feedback_content_type",
                    models.CharField(
                        choices=[("text", "Plain text"), ("html", "HTML")],
                        default="html",
                        max_length=64,
                    ),
                ),
            ],
            options={
                "verbose_name": "Agents",
                "abstract": False,
            },
        ),
    ]
